<?php

namespace MDT\Apple_News_Core_Enhancements;

/**
 * Class Gutenberg
 *
 * @package MDT\Apple_News_Core_Enhancements
 */
class Gutenberg {

	const PUBLISH_META_KEY = 'mdt-publish-to-apple-news';

	/**
	 * Init
	 */
	public static function init() {
		add_action( 'enqueue_block_editor_assets', array( __CLASS__, 'enqueue_block_editor_assets' ) );
		add_action( 'init', array( __CLASS__, 'add_actions' ) );
	}

	/**
	 * Admin actions
	 */
	public static function add_actions() {
		add_action( 'rest_api_init', array( __CLASS__, 'register_rest_field' ) );
	}


	/**
	 * Enqueue the block editor plugin script
	 */
	public static function enqueue_block_editor_assets() {
		if ( in_array( get_post_type(), Admin::get_allowed_post_types(), true ) ) {
			$asset_data = include __DIR__ . '/build/index.asset.php';
			wp_enqueue_script(
				'mdt-gutenberg-apple-news',
				plugin_dir_url( __FILE__ ) . 'build/index.js',
				$asset_data['dependencies'],
				$asset_data['version'],
				true
			);
			wp_enqueue_style(
				'mdt-gutenberg-apple-news',
				plugin_dir_url( __FILE__ ) . 'build/index.css',
				array(),
				$asset_data['version']
			);
		}
	}

	/**
	 * Exposing the 'mdt-publish-to-apple-news' meta value to the rest api so that we can read/write to it from
	 * a Gutenberg plugin
	 */
	public static function register_rest_field() {
		register_rest_field(
			Admin::get_allowed_post_types(),
			'publish_to_apple_news',
			array(
				'get_callback'    => array( __CLASS__, 'get_meta' ),
				'update_callback' => array( __CLASS__, 'update_meta' ),
			)
		);
	}

	/**
	 * Fetches the meta value for use in the rest api. If a value doesn't already exist we
	 * return true as the default.
	 *
	 * @param array $object REST API object
	 * @return bool The meta value
	 */
	public static function get_meta( $object ) {
		$post_id = $object['id'];
		$default_value = apply_filters( 'mdt_apple_news_ce_default_auto_publish', true, $post_id );
		
		if ( metadata_exists( 'post', $post_id, self::PUBLISH_META_KEY ) ) {	
			$meta_value = get_post_meta( $post_id, self::PUBLISH_META_KEY, true );
			return filter_var( $meta_value, FILTER_VALIDATE_BOOLEAN );
		}

		return $default_value;
	}

	/**
	 * Updates the meta value
	 *
	 * @param bool     $value The value to update
	 * @param \WP_Post $post  The post object
	 */
	public static function update_meta( $value, $post ) {
		$publish = filter_var( $value, FILTER_VALIDATE_BOOLEAN );
		update_post_meta( $post->ID, self::PUBLISH_META_KEY, $publish );
	}
}

Gutenberg::init();

